==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-session/lxqt-session_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_BA">
<context>
    <name>AutoStartEdit</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Уреди</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Име:</translation>
    </message>
    <message>
        <source>Search...</source>
        <translation type="vanished">Тражи...</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation type="vanished">Наредба:</translation>
    </message>
    <message>
        <source>Select Application</source>
        <translation type="vanished">Изабери програм</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <source>Global Autostart</source>
        <translation type="vanished">Глобално аутопокретање</translation>
    </message>
    <message>
        <source>LXQt Autostart</source>
        <translation type="vanished">Рејзорово аутопокретање</translation>
    </message>
</context>
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="302"/>
        <source>Crash Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="303"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Openbox - light-weight window manager</source>
        <translation type="vanished">Опенбокс - лагани менаџер прозора</translation>
    </message>
    <message>
        <source>KWin - window manager of the KDE Software Compilation</source>
        <translation type="vanished">КВин - менаџер прозора за КДЕ</translation>
    </message>
    <message>
        <source>Metacity - window manager of the GNOME desktop environment</source>
        <translation type="vanished">Метасити - менаџер прозора за ГНОМ</translation>
    </message>
    <message>
        <source>Windowmaker - a classical lightweight window manager</source>
        <translation type="vanished">Виндоумејкер - класични лагани менаџер прозора</translation>
    </message>
    <message>
        <source>Enlightenement 16</source>
        <translation type="vanished">Enlightenement 16</translation>
    </message>
    <message>
        <source>Fvwm2 - a classical lightweight window manager</source>
        <translation type="vanished">Fvwm2 - класични лагани менаџер прозора</translation>
    </message>
    <message>
        <source>Xfwm4 - a window manager for the Xfce desktop environment</source>
        <translation type="vanished">Xfwm4 - менаџер прозора за Иксфце</translation>
    </message>
    <message>
        <source>Sawfish - a lightweight, flexible window manager</source>
        <translation type="vanished">Софиш - лагани, прилагодиви менаџер прозора</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Добро дошли у Рејзор-кјут</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation type="vanished">&lt;b&gt;Добро дошли у Рејзор-кјут&lt;/b&gt;
&lt;p&gt;
Прије него почнете да користите Рејзор-кјут морате да изаберете менаџер прозора:</translation>
    </message>
    <message>
        <source>You can change the Window Manager later at any time via LXQt Session Configurator.</source>
        <translation type="vanished">Можете да промијените менаџера прозора касније помоћу Рејзоровог Подешавања сесије.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-session/lxqt-session/lxqt-session_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_BA">
<context>
    <name>AutoStartEdit</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Уреди</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Име:</translation>
    </message>
    <message>
        <source>Search...</source>
        <translation type="vanished">Тражи...</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation type="vanished">Наредба:</translation>
    </message>
    <message>
        <source>Select Application</source>
        <translation type="vanished">Изабери програм</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <source>Global Autostart</source>
        <translation type="vanished">Глобално аутопокретање</translation>
    </message>
    <message>
        <source>LXQt Autostart</source>
        <translation type="vanished">Рејзорово аутопокретање</translation>
    </message>
</context>
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="309"/>
        <source>Crash Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="310"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Openbox - light-weight window manager</source>
        <translation type="vanished">Опенбокс - лагани менаџер прозора</translation>
    </message>
    <message>
        <source>KWin - window manager of the KDE Software Compilation</source>
        <translation type="vanished">КВин - менаџер прозора за КДЕ</translation>
    </message>
    <message>
        <source>Metacity - window manager of the GNOME desktop environment</source>
        <translation type="vanished">Метасити - менаџер прозора за ГНОМ</translation>
    </message>
    <message>
        <source>Windowmaker - a classical lightweight window manager</source>
        <translation type="vanished">Виндоумејкер - класични лагани менаџер прозора</translation>
    </message>
    <message>
        <source>Enlightenement 16</source>
        <translation type="vanished">Enlightenement 16</translation>
    </message>
    <message>
        <source>Fvwm2 - a classical lightweight window manager</source>
        <translation type="vanished">Fvwm2 - класични лагани менаџер прозора</translation>
    </message>
    <message>
        <source>Xfwm4 - a window manager for the Xfce desktop environment</source>
        <translation type="vanished">Xfwm4 - менаџер прозора за Иксфце</translation>
    </message>
    <message>
        <source>Sawfish - a lightweight, flexible window manager</source>
        <translation type="vanished">Софиш - лагани, прилагодиви менаџер прозора</translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <source>Configuration file path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>Window manager to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Добро дошли у Рејзор-кјут</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation type="vanished">&lt;b&gt;Добро дошли у Рејзор-кјут&lt;/b&gt;
&lt;p&gt;
Прије него почнете да користите Рејзор-кјут морате да изаберете менаџер прозора:</translation>
    </message>
    <message>
        <source>You can change the Window Manager later at any time via LXQt Session Configurator.</source>
        <translation type="vanished">Можете да промијените менаџера прозора касније помоћу Рејзоровог Подешавања сесије.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
